@@ -7,7 +7,7 @@ from django.urls import reverse
 import pytest
 from rest_framework import status
 
-from swh.deposit.api.checks import ALTERNATE_FIELDS_MISSING, MANDATORY_FIELDS_MISSING
+from swh.deposit.api.checks import MANDATORY_FIELDS_MISSING
 from swh.deposit.api.private.deposit_check import (
     MANDATORY_ARCHIVE_INVALID,
     MANDATORY_ARCHIVE_MISSING,
@@ -130,13 +130,15 @@ def test_deposit_ko_unsupported_tarball(
         assert len(details["archive"]) == 1
         assert details["archive"][0]["summary"] == MANDATORY_ARCHIVE_UNSUPPORTED
         # metadata check failure
-        assert len(details["metadata"]) == 2
+        assert len(details["metadata"]) == 1
         mandatory = details["metadata"][0]
         assert mandatory["summary"] == MANDATORY_FIELDS_MISSING
-        assert set(mandatory["fields"]) == set(["author"])
-        alternate = details["metadata"][1]
-        assert alternate["summary"] == ALTERNATE_FIELDS_MISSING
-        assert alternate["fields"] == ["name or title"]
+        assert set(mandatory["fields"]) == set(
+            [
+                "atom:author or codemeta:author",
+                "atom:name or atom:title or codemeta:name",
+            ]
+        )
 
         deposit = Deposit.objects.get(pk=deposit.id)
         assert deposit.status == DEPOSIT_STATUS_REJECTED
@@ -200,9 +202,9 @@ def create_deposit_archive_with_archive(
     # then
     assert response.status_code == status.HTTP_201_CREATED
     response_content = parse_xml(response.content)
-    deposit_status = response_content["deposit_status"]
+    deposit_status = response_content["swh:deposit_status"]
     assert deposit_status == DEPOSIT_STATUS_DEPOSITED
-    deposit_id = int(response_content["deposit_id"])
+    deposit_id = int(response_content["swh:deposit_id"])
 
     deposit = Deposit.objects.get(pk=deposit_id)
     assert DEPOSIT_STATUS_DEPOSITED == deposit.status
