@@ -9,17 +9,14 @@ import json
 from django.urls import reverse
 from rest_framework import status
 
-from swh.model.identifiers import DIRECTORY, persistent_identifier, REVISION, SNAPSHOT
-
 from swh.deposit.api.private.deposit_update_status import MANDATORY_KEYS
-
-from swh.deposit.models import Deposit
 from swh.deposit.config import (
-    PRIVATE_PUT_DEPOSIT,
-    DEPOSIT_STATUS_LOAD_SUCCESS,
     DEPOSIT_STATUS_LOAD_FAILURE,
+    DEPOSIT_STATUS_LOAD_SUCCESS,
+    PRIVATE_PUT_DEPOSIT,
 )
-
+from swh.deposit.models import Deposit
+from swh.model.identifiers import DIRECTORY, REVISION, SNAPSHOT, swhid
 
 PRIVATE_PUT_DEPOSIT_NC = PRIVATE_PUT_DEPOSIT + "-nc"
 
@@ -53,12 +50,12 @@ def test_update_deposit_status_success_with_info(
         "origin_url": origin_url,
     }
     for url in private_check_url_endpoints(deposit_collection, deposit):
-        dir_id = persistent_identifier(DIRECTORY, directory_id)
-        rev_id = persistent_identifier(REVISION, revision_id)
-        snp_id = persistent_identifier(SNAPSHOT, snapshot_id)
+        dir_id = swhid(DIRECTORY, directory_id)
+        rev_id = swhid(REVISION, revision_id)
+        snp_id = swhid(SNAPSHOT, snapshot_id)
 
-        expected_swh_id = "swh:1:dir:%s" % directory_id
-        expected_swh_id_context = (
+        expected_swhid = "swh:1:dir:%s" % directory_id
+        expected_swhid_context = (
             f"{dir_id};origin={origin_url};" + f"visit={snp_id};anchor={rev_id};path=/"
         )
 
@@ -70,8 +67,8 @@ def test_update_deposit_status_success_with_info(
 
         deposit = Deposit.objects.get(pk=deposit.id)
         assert deposit.status == expected_status
-        assert deposit.swh_id == expected_swh_id
-        assert deposit.swh_id_context == expected_swh_id_context
+        assert deposit.swhid == expected_swhid
+        assert deposit.swhid_context == expected_swhid_context
 
         # Reset deposit
         deposit = ready_deposit_verified
@@ -98,8 +95,8 @@ def test_update_deposit_status_rejected_with_info(
         deposit = Deposit.objects.get(pk=deposit.id)
         assert deposit.status == DEPOSIT_STATUS_LOAD_FAILURE
 
-        assert deposit.swh_id is None
-        assert deposit.swh_id_context is None
+        assert deposit.swhid is None
+        assert deposit.swhid_context is None
 
         # Reset status
         deposit = ready_deposit_verified
@@ -158,6 +155,7 @@ def test_update_deposit_status_will_fail_with_unknown_status(
         )
 
         assert response.status_code == status.HTTP_400_BAD_REQUEST
+        assert b"Possible status in " in response.content
 
 
 def test_update_deposit_status_will_fail_with_no_status_key(
@@ -175,12 +173,13 @@ def test_update_deposit_status_will_fail_with_no_status_key(
         )
 
         assert response.status_code == status.HTTP_400_BAD_REQUEST
+        assert b"The status key is mandatory with possible values" in response.content
 
 
-def test_update_deposit_status_success_without_swh_id_fail(
+def test_update_deposit_status_success_without_swhid_fail(
     authenticated_client, deposit_collection, ready_deposit_verified
 ):
-    """Providing successful status without swh_id should return a 400
+    """Providing successful status without swhid should return a 400
 
     """
     deposit = ready_deposit_verified
@@ -192,3 +191,6 @@ def test_update_deposit_status_success_without_swh_id_fail(
         )
 
         assert response.status_code == status.HTTP_400_BAD_REQUEST
+        assert (
+            b"Updating deposit status to done requires information" in response.content
+        )
