@@ -21,7 +21,6 @@ from swh.deposit.cli.client import (
     _collection,
     _url,
     generate_metadata,
-    generate_slug,
 )
 from swh.deposit.client import MaintenanceError, PublicApiDepositClient
 from swh.deposit.parsers import parse_xml
@@ -30,6 +29,15 @@ from swh.model.exceptions import ValidationError
 from ..conftest import TEST_USER
 
 
+def generate_slug() -> str:
+    """Generate a slug (sample purposes).
+
+    """
+    import uuid
+
+    return str(uuid.uuid4())
+
+
 @pytest.fixture
 def datadir(request):
     """Override default datadir to target main test datadir"""
